@@ -1,4 +1,4 @@
-/* $Id: child.c,v 1.5 2002/06/27 16:29:21 rjkaes Exp $
+/* $Id: child.c,v 1.11 2003/05/31 23:02:21 rjkaes Exp $
  *
  * Handles the creation/destruction of the various children required for
  * processing incoming connections.
@@ -164,8 +164,11 @@ child_main(struct child_s* ptr)
 	socklen_t clilen;
 
 	cliaddr = safemalloc(addrlen);
-	if (!cliaddr)
+	if (!cliaddr) {
+		log_message(LOG_CRIT,
+			    "Could not allocate memory for child address.");
 		exit(0);
+	}
 
 	ptr->connects = 0;
 
@@ -176,7 +179,19 @@ child_main(struct child_s* ptr)
 
 		connfd = accept(listenfd, cliaddr, &clilen);
 
-		DEBUG2("Process %u has accepted connection", ptr->tid);
+#ifndef NDEBUG
+		/*
+		 * Enable the TINYPROXY_DEBUG environment variable if you
+		 * want to use the GDB debugger.
+		 */
+		if (getenv("TINYPROXY_DEBUG")) {
+			/* Pause for 10 seconds to allow us to connect debugger */
+			fprintf(stderr,
+				"Process has accepted connection: %u\n", ptr->tid);
+			sleep(10);
+			fprintf(stderr, "Continuing process: %u\n", ptr->tid);
+		}
+#endif
 
 		/*
 		 * Make sure no error occurred...
@@ -197,12 +212,10 @@ child_main(struct child_s* ptr)
 
 			DEBUG2("%u connections so far...", ptr->connects);
 
-			if (ptr->connects >= child_config.maxrequestsperchild) {
+			if (ptr->connects == child_config.maxrequestsperchild - 1) {
 				log_message(LOG_NOTICE,
-					    "Child has reached MaxRequestsPerChild (%u > %u). Killing child.",
-					    ptr->connects,
-					    child_config.maxrequestsperchild);
-
+					    "Child has reached MaxRequestsPerChild (%u). Killing child.",
+					    ptr->connects);
 				break;
 			}
 		}
@@ -306,12 +319,12 @@ child_pool_create(void)
 		child_config.startservers = child_config.maxclients;
 	}
 
-	for (i = 0; i < child_config.maxclients; i++) {
+	for (i = 0; i != child_config.maxclients; i++) {
 		child_ptr[i].status = T_EMPTY;
 		child_ptr[i].connects = 0;
 	}
 
-	for (i = 0; i < child_config.startservers; i++) {
+	for (i = 0; i != child_config.startservers; i++) {
 		DEBUG2("Trying to create child %d of %d", i + 1, child_config.startservers);
 		child_ptr[i].status = T_WAITING;
 		child_ptr[i].tid = child_make(&child_ptr[i]);
@@ -357,7 +370,7 @@ child_main_loop(void)
 
 			SERVER_COUNT_UNLOCK();
 
-			for (i = 0; i < child_config.maxclients; i++) {
+			for (i = 0; i != child_config.maxclients; i++) {
 				if (child_ptr[i].status == T_EMPTY) {
 					child_ptr[i].status = T_WAITING;
 					child_ptr[i].tid = child_make(&child_ptr[i]);
@@ -382,6 +395,8 @@ child_main_loop(void)
 
 		/* Handle log rotation if it was requested */
 		if (received_sighup) {
+			truncate_log_file();
+
 #ifdef FILTER_ENABLE
 			if (config.filter) {
 				filter_destroy();
@@ -403,7 +418,7 @@ child_kill_children(void)
 {
 	int i;
 	
-	for (i = 0; i < child_config.maxclients; i++) {
+	for (i = 0; i != child_config.maxclients; i++) {
 		if (child_ptr[i].status != T_EMPTY)
 			kill(child_ptr[i].tid, SIGTERM);
 	}
